@@ -1,7 +1,7 @@
 /*
  *  Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
  *  Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
- *  Copyright © 2007 Christian Persch
+ *  Copyright © 2007, 2008 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,11 +16,9 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- *  $Id$
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <unistd.h>
@@ -43,11 +41,14 @@
 #include <gdk/gdkspawn.h>
 #endif
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
+#ifdef HAVE_MAEMO_3
 #include <hildon-widgets/hildon-banner.h>
+#else
+#include <hildon/hildon-banner.h>
 #endif
+#endif /* HAVE_HILDON */
 
-#include <libgames-support/games-card-common.h>
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
@@ -90,7 +91,7 @@ enum
   ACTION_OPTIONS_MENU,
   ACTION_DEAL,
   ACTION_HINT,
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   ACTION_ACCEL_UNDO_MOVE,
 #endif
 #ifndef HAVE_MAEMO
@@ -104,7 +105,7 @@ struct _AisleriotWindowPrivate
   AisleriotGame *game;
   AisleriotBoard *board;
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   GtkLabel *game_message_label;
   guint game_message_hash;
 #else
@@ -136,7 +137,7 @@ struct _AisleriotWindowPrivate
   GtkListStore *game_choice_store;
   GtkTreeSelection *game_choice_selection;
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   GtkWidget *hint_dialog;
 #endif
 
@@ -206,13 +207,13 @@ select_game_cb (GtkAction *action,
   GtkWidget *dialog;
   GtkListStore *list;
   GtkWidget *list_view;
-  GtkTreeSelection *select;
+  GtkTreeSelection *selection;
   GtkWidget *scrolled_window;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
   GamesFileList *files;
   GtkWidget *hbox;
-  GtkTreeIter iter, current_iter;
+  GtkTreeIter current_iter, selection_iter;
   gboolean current_iter_set = FALSE;
   const char *current_game_file;
   GList *l;
@@ -266,7 +267,7 @@ select_game_cb (GtkAction *action,
                                         GTK_WINDOW (window),
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        _("_Select"), GTK_RESPONSE_OK,
                                         NULL);
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
                                            GTK_RESPONSE_OK,
@@ -296,8 +297,8 @@ select_game_cb (GtkAction *action,
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
 
-  priv->game_choice_selection = select = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
-  gtk_tree_selection_set_mode (select, GTK_SELECTION_BROWSE);
+  priv->game_choice_selection = selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
@@ -330,13 +331,13 @@ select_game_cb (GtkAction *action,
    * and scroll to it.
    */
   if (current_iter_set) {
-    gtk_tree_selection_select_iter (select, &current_iter);
+    gtk_tree_selection_select_iter (selection, &current_iter);
   }
 
-  if (gtk_tree_selection_get_selected (select, NULL, &iter)) {
+  if (gtk_tree_selection_get_selected (selection, NULL, &selection_iter)) {
     GtkTreePath *path;
 
-    path = gtk_tree_model_get_path (GTK_TREE_MODEL (list), &iter);
+    path = gtk_tree_model_get_path (GTK_TREE_MODEL (list), &selection_iter);
     gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (list_view), path, NULL,
                                   TRUE,
 				  0.5, 0.0);
@@ -418,12 +419,12 @@ show_game_over_dialog (AisleriotWindow *window)
                                                "<b>%s</b>",
                                                message);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   /* Empty title shows up as "<unnamed>" on maemo */
   gtk_window_set_title (GTK_WINDOW (dialog), _("Game Over"));
 #else
   gtk_window_set_title (GTK_WINDOW (dialog), "");
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
@@ -565,6 +566,7 @@ help_about_cb (GtkAction *action,
     "Rosanna Yuen <zana@webwynk.net>",
     "Alan Horkan <horkana@maths.tcd.ie>",
     "Richard Hoelscher <rah@rahga.com>",
+    "Vincent Povirk",
     NULL
   };
   const char *artists[] = {
@@ -600,7 +602,7 @@ help_about_cb (GtkAction *action,
                          "version", VERSION,
                          "title", priv->freecell_mode ? _("About FreeCell Solitaire")
                                                       : _("About AisleRiot"),
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
                          /* The long text makes the dialogue too large under maemo */
                          "comments",
                          priv->freecell_mode ?
@@ -611,7 +613,7 @@ help_about_cb (GtkAction *action,
 			     "AisleRiot is a part of GNOME Games."),
 #endif
                          "copyright", "Copyright © 1998-2006 Jonathan Blandford\n"
-                                      "Copyright © 2007 Christian Persch",
+                                      "Copyright © 2007, 2008 Christian Persch",
                          "license", licence,
                          "authors", authors,
                          "artists", artists,
@@ -686,7 +688,7 @@ statistics_cb (GtkAction *action,
 
 #ifdef ENABLE_DEBUG_UI
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
 
 static void
 move_to_next_screen_cb (GtkAction *action,
@@ -782,7 +784,7 @@ debug_cycle_cb (GtkAction *action,
   g_timeout_add (500, (GSourceFunc) debug_cycle_timeout_cb, data);
 }
 
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 
 static void
 debug_choose_seed_response_cb (GtkWidget *dialog,
@@ -924,7 +926,6 @@ static void
 sound_toggle_cb (GtkToggleAction *action,
                  AisleriotWindow *window)
 {
-  AisleriotWindowPrivate *priv = window->priv;
   gboolean sound_enabled;
 
   sound_enabled = gtk_toggle_action_get_active (action);
@@ -942,14 +943,14 @@ show_hint_cb (GtkAction *action,
   SCM hint, string1, string2;
   char *message = NULL;
   char *str1, *str2;
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   GtkWidget *dialog;
 #endif
 
   /* If the game hasn't started yet, getting a hint starts it */
   aisleriot_game_start (priv->game);
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   if (priv->hint_dialog) {
     gtk_widget_destroy (priv->hint_dialog);
     priv->hint_dialog = NULL;
@@ -1060,7 +1061,7 @@ show_hint_cb (GtkAction *action,
   if (!message)
     return;
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   hildon_banner_show_information (GTK_WIDGET (window),
                                   NULL,
                                   message);
@@ -1081,7 +1082,7 @@ show_hint_cb (GtkAction *action,
                     G_CALLBACK (gtk_widget_destroy), NULL);
   g_signal_connect (dialog, "destroy",
                     G_CALLBACK (gtk_widget_destroyed), &priv->hint_dialog);
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
   g_free (message);
 }
@@ -1397,11 +1398,11 @@ install_recently_played_menu (AisleriotWindow *window)
 
     g_snprintf (actionname, sizeof (actionname), "Recent%d", i);
     game_name = aisleriot_util_get_display_filename (recent_games[i]);
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
     tooltip = NULL;
 #else
     tooltip = g_strdup_printf (_("Play \"%s\""), game_name);
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
     action = gtk_action_new (actionname, game_name, tooltip, NULL);
     g_free (game_name);
     g_free (tooltip);
@@ -1501,7 +1502,7 @@ install_card_theme_menu (AisleriotWindow *window)
     display_name = aisleriot_util_get_display_filename (theme);
 
     g_snprintf (actionname, sizeof (actionname), "Theme%d", i);
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
     tooltip = NULL;
 #else
     tooltip = g_strdup_printf (_("Display cards with \"%s\" card theme"), display_name);
@@ -1542,7 +1543,7 @@ install_card_theme_menu (AisleriotWindow *window)
 
 /* Callbacks */
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
 
 static void
 sync_window_topmost_cb (AisleriotWindow *window,
@@ -1559,11 +1560,11 @@ sync_window_topmost_cb (AisleriotWindow *window,
   }
 }
 
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
 /* Game state synchronisation */
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
 
 static void
 sync_game_score (AisleriotGame *game,
@@ -1584,7 +1585,7 @@ sync_game_score (AisleriotGame *game,
   gtk_label_set_text (GTK_LABEL (priv->score_label), str);
 }
 
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 
 static void
 sync_game_state (AisleriotGame *game,
@@ -1608,7 +1609,7 @@ sync_game_state (AisleriotGame *game,
   gtk_action_set_sensitive (priv->action[ACTION_HINT],
                             state == GAME_BEGIN || state == GAME_RUNNING);
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   if (state == GAME_RUNNING) {
     games_clock_start (GAMES_CLOCK (priv->clock));
   } else {
@@ -1633,7 +1634,7 @@ sync_game_undoable (AisleriotGame *game,
   g_object_get (game, "can-undo", &enabled, NULL);
 
   gtk_action_set_sensitive (priv->action[ACTION_UNDO_MOVE], enabled);
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   gtk_action_set_sensitive (priv->action[ACTION_ACCEL_UNDO_MOVE], enabled);
 #endif
 
@@ -1675,9 +1676,9 @@ game_type_changed_cb (AisleriotGame *game,
   char *game_name;
   guint features;
   gboolean dealable;
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   gboolean show_scores;
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 
   priv->changing_game_type = TRUE;
 
@@ -1703,7 +1704,7 @@ game_type_changed_cb (AisleriotGame *game,
   dealable = (features & FEATURE_DEALABLE) != 0;
   gtk_action_set_visible (priv->action[ACTION_DEAL], dealable);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   gtk_label_set_text (priv->game_message_label, NULL);
 #else
   games_clock_set_seconds (GAMES_CLOCK (priv->clock), 0);
@@ -1725,7 +1726,7 @@ game_new_cb (AisleriotGame *game,
 
   update_statistics_display (window);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   gtk_label_set_text (priv->game_message_label, NULL);
 #else
   games_clock_set_seconds (GAMES_CLOCK (priv->clock), 0);
@@ -1740,7 +1741,7 @@ game_statusbar_message_cb (AisleriotGame *game,
                            AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   gtk_label_set_text (priv->game_message_label, message);
 
   /* The banners are annoying, but until I get a better idea, use them
@@ -1769,7 +1770,7 @@ game_statusbar_message_cb (AisleriotGame *game,
   if (message != NULL) {
     gtk_statusbar_push (priv->statusbar, id, message);
   }
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 }
 
 static void
@@ -1786,13 +1787,13 @@ game_exception_response_cb (GtkWidget *dialog,
   if (response == GTK_RESPONSE_ACCEPT) {
     GError *err = NULL;
     char pidstr[64];
-    char *argv[] = {
+    const char * const argv[] = {
       "bug-buddy",
       "--package", "gnome-games",
       "--package-ver", VERSION,
       "--appname", "aisleriot",
       "--pid", pidstr,
-      "--include", (char *) error_file,
+      "--include", (const char *) error_file,
       NULL
     };
 
@@ -1800,7 +1801,7 @@ game_exception_response_cb (GtkWidget *dialog,
 
     if (!gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (window)),
                               NULL /* working dir */,
-                              argv,
+                              (char **) argv,
                               NULL /* envp */,
                               G_SPAWN_SEARCH_PATH,
                               NULL, NULL,
@@ -1840,12 +1841,12 @@ game_exception_cb (AisleriotGame *game,
     (GTK_MESSAGE_DIALOG (dialog),
      "%s", _("Please report this bug to the developers."));
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   /* Empty title shows up as "<unnamed>" on maemo */
   gtk_window_set_title (GTK_WINDOW (dialog), _("Error"));
 #else
   gtk_window_set_title (GTK_WINDOW (dialog), "");
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
@@ -1869,7 +1870,7 @@ game_exception_cb (AisleriotGame *game,
 
 /* Class implementation */
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
 G_DEFINE_TYPE (AisleriotWindow, aisleriot_window, HILDON_TYPE_WINDOW);
 #else
 G_DEFINE_TYPE (AisleriotWindow, aisleriot_window, GTK_TYPE_WINDOW);
@@ -1890,16 +1891,16 @@ aisleriot_window_state_event (GtkWidget *widget,
 
     set_fullscreen_actions (window, is_fullscreen);
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
 #if GTK_CHECK_VERSION (2, 11, 0)
     gtk_statusbar_set_has_resize_grip (priv->statusbar, !is_maximised && !is_fullscreen);
 #else
     gtk_statusbar_set_has_resize_grip (priv->statusbar, FALSE);
 #endif
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
   }
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   if (event->changed_mask & GDK_WINDOW_STATE_ICONIFIED) {
     if (aisleriot_game_get_state (priv->game) == GAME_RUNNING) {
       gboolean is_iconified;
@@ -1914,7 +1915,7 @@ aisleriot_window_state_event (GtkWidget *widget,
       }
     }
   }
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 
   if (GTK_WIDGET_CLASS (aisleriot_window_parent_class)->window_state_event) {
     return GTK_WIDGET_CLASS (aisleriot_window_parent_class)->window_state_event (widget, event);
@@ -1923,7 +1924,7 @@ aisleriot_window_state_event (GtkWidget *widget,
   return FALSE;
 }
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
 /* We never show tooltips, no need to put them into the binary */
 #define ACTION_TOOLTIP(string)  (NULL)
 #define ACTION_ACCEL(string1,string2) (string2)
@@ -1946,9 +1947,10 @@ aisleriot_window_init (AisleriotWindow *window)
     /* Menu item actions */
     { "NewGame", GAMES_STOCK_NEW_GAME, NULL,
       ACTION_ACCEL ("<ctrl>N", NULL),
-      NULL,
+      ACTION_TOOLTIP (N_("Start a new game")),
       G_CALLBACK (new_game_cb) },
-    { "RestartGame", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL,
+    { "RestartGame", GAMES_STOCK_RESTART_GAME, NULL, NULL,
+       ACTION_TOOLTIP (N_("Restart the game")),
       G_CALLBACK (restart_game) },
     { "Select", GTK_STOCK_INDEX, N_("_Select Game..."),
       ACTION_ACCEL ("<ctrl>O", NULL),
@@ -1958,16 +1960,20 @@ aisleriot_window_init (AisleriotWindow *window)
     { "Statistics", GTK_STOCK_ADD, N_("S_tatistics"), NULL,
       ACTION_TOOLTIP (N_("Show gameplay statistics")),
       G_CALLBACK (statistics_cb) },
-    { "CloseWindow", GTK_STOCK_CLOSE, NULL, NULL, NULL,
+    { "CloseWindow", GTK_STOCK_CLOSE, NULL, NULL,
+      ACTION_TOOLTIP (N_("Close this window")),
       G_CALLBACK (close_window_cb) },
-    { "UndoMove", GAMES_STOCK_UNDO_MOVE, NULL, NULL, NULL,
+    { "UndoMove", GAMES_STOCK_UNDO_MOVE, NULL, NULL,
+      ACTION_TOOLTIP (N_("Undo the last move")),
       G_CALLBACK (undo_cb) },
-    { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL, NULL,
+    { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL,
+      ACTION_TOOLTIP (N_("Redo the undone move")),
       G_CALLBACK (redo_cb) },
     { "Deal", GTK_STOCK_OK /* FIXMEchpe */, _("_Deal"), "<control>D",
       ACTION_TOOLTIP (N_("Deal next card or cards")),
       G_CALLBACK (deal_cb) },
-    { "Hint", GAMES_STOCK_HINT, NULL, NULL, NULL,
+    { "Hint", GAMES_STOCK_HINT, NULL, NULL,
+      ACTION_TOOLTIP (N_("Get a hint for your next move")),
       G_CALLBACK (show_hint_cb) },
     { "Contents", GAMES_STOCK_CONTENTS, NULL, NULL,
       ACTION_TOOLTIP (N_("View help for Aisleriot")),
@@ -1976,14 +1982,17 @@ aisleriot_window_init (AisleriotWindow *window)
       ACTION_ACCEL ("<shift>F1", NULL),
       ACTION_TOOLTIP (N_("View help for this game")),
       G_CALLBACK (help_on_game_cb) },
-    { "About", GTK_STOCK_ABOUT, NULL, NULL, NULL,
+    { "About", GTK_STOCK_ABOUT, NULL, NULL,
+      ACTION_TOOLTIP (N_("About this game")),
       G_CALLBACK (help_about_cb) },
 
     /* Toolbar-only actions */
 #ifndef HAVE_MAEMO
     { "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL,
       G_CALLBACK (leave_fullscreen_cb) },
+#ifndef HAVE_HILDON
     { "ThemeMenu", NULL, N_("_Card Style"), NULL, NULL, NULL },
+#endif /* !HAVE_HILDON */
 #endif /* !HAVE_MAEMO */
 
 #ifdef ENABLE_DEBUG_UI
@@ -1991,7 +2000,7 @@ aisleriot_window_init (AisleriotWindow *window)
     { "DebugMenu", NULL, "_Debug" },
     { "DebugChooseSeed", NULL, "_Choose seed", NULL, NULL,
       G_CALLBACK (debug_choose_seed_cb) },
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
     { "DebugMoveNextScreen", NULL, "_Move to next screen", NULL, NULL,
        G_CALLBACK (move_to_next_screen_cb) },
     { "DebugDelayedMoveNextScreen", NULL, "_Delayed move to next screen", NULL, NULL,
@@ -2000,11 +2009,11 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (debug_exception_cb) },
     { "DebugCycle", NULL, "Cycle through _all games", NULL, NULL,
       G_CALLBACK (debug_cycle_cb) },
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 #endif /* ENABLE_DEBUG_UI */
 
     /* Accel actions */
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
     { "AccelUndoMove", NULL, "AccelUndoMove", "Escape", NULL,
       G_CALLBACK (undo_cb) },
 #endif
@@ -2043,9 +2052,9 @@ aisleriot_window_init (AisleriotWindow *window)
     "OptionsMenu",
     "Deal",
     "Hint",
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
     "AccelUndoMove",
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 #ifndef HAVE_MAEMO
     "LeaveFullscreen",
 #endif /* !HAVE_MAEMO */
@@ -2053,7 +2062,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
   static const char ui_description[] =
     "<ui>"
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
       "<popup name='MainMenu'>"
         "<menu action='GameMenu'>"
           "<menuitem action='NewGame'/>"
@@ -2093,7 +2102,7 @@ aisleriot_window_init (AisleriotWindow *window)
 #endif /* ENABLE_DEBUG_UI */
         "<menuitem action='CloseWindow'/>"
       "</popup>"
-#else /* !HAVE_MAEMO */
+#else /* !HAVE_HILDON */
       "<menubar name='MainMenu'>"
         "<menu action='GameMenu'>"
           "<menuitem action='NewGame'/>"
@@ -2137,7 +2146,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "</menu>"
 #endif /* ENABLE_DEBUG_UI */
       "</menubar>"
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
       "<toolbar name='Toolbar'>"
         "<toolitem action='NewGame'/>"
         "<toolitem action='RestartGame'/>"
@@ -2154,7 +2163,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<separator/>"
 #endif
       "</toolbar>"
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
       "<accelerator action='AccelUndoMove'/>"
 #endif
     "</ui>";
@@ -2165,7 +2174,7 @@ aisleriot_window_init (AisleriotWindow *window)
   GtkAction *action;
   char *theme;
   guint i;
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   GtkToolItem *tool_item;
 #else
   const char *env;
@@ -2179,13 +2188,18 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->game = aisleriot_game_new ();
 
-#ifdef HAVE_MAEMO
+  /* FIXMEchpe: case HAVE_HILDON && HAVE_RSVG ! */
+#ifdef HAVE_HILDON
   priv->scalable_cards = FALSE;
   priv->use_pixbuf_drawing = FALSE;
 #else
+#ifdef HAVE_RSVG
   /* Default to scalable */
   env = g_getenv ("AISLERIOT_CARDS_SCALABLE");
   priv->scalable_cards = env == NULL || g_ascii_strtoull (env, NULL, 0) != 0;
+#else
+  priv->scalable_cards = FALSE;
+#endif /* HAVE_RSVG */
 
   /* Default to pixbuf drawing */
   env = g_getenv ("AISLERIOT_PIXBUF_DRAWING");
@@ -2201,7 +2215,8 @@ aisleriot_window_init (AisleriotWindow *window)
     g_print ("Using pixbuf drawing method\n");
   else
     g_print ("Using pixmap drawing method\n");
-#endif
+#endif /* GNOME_ENABLE_DEBUG */
+
 #endif /* HAVE_MAEMO */
 
   priv->board = AISLERIOT_BOARD (aisleriot_board_new (priv->game, priv->scalable_cards));
@@ -2248,7 +2263,7 @@ aisleriot_window_init (AisleriotWindow *window)
   action = gtk_action_group_get_action (priv->action_group, "Select");
   g_object_set (action, "short-label", _("Select Game"), NULL);
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   statusbar = priv->statusbar = GTK_STATUSBAR (gtk_statusbar_new ());
   priv->game_message_id = gtk_statusbar_get_context_id (priv->statusbar, "game-message");
   games_stock_prepare_for_statusbar_tooltips (priv->ui_manager,
@@ -2281,6 +2296,9 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_box_pack_start (GTK_BOX (priv->score_box), priv->score_label, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (statusbar_hbox), priv->score_box, FALSE, FALSE, 0);
 
+  aisleriot_util_add_atk_relation (label, priv->score_label, ATK_RELATION_LABEL_FOR);
+  aisleriot_util_add_atk_relation (priv->score_label, label, ATK_RELATION_LABELLED_BY);
+
   time_box = gtk_hbox_new (12, FALSE);
   label = gtk_label_new (_("Time:"));
   gtk_box_pack_start (GTK_BOX (time_box), label, FALSE, FALSE, 0);
@@ -2288,7 +2306,10 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_box_pack_start (GTK_BOX (time_box), priv->clock, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (statusbar_hbox), time_box, FALSE, FALSE, 0);
   gtk_widget_show_all (time_box);
-#endif /* !HAVE_MAEMO */
+
+  aisleriot_util_add_atk_relation (label, priv->clock, ATK_RELATION_LABEL_FOR);
+  aisleriot_util_add_atk_relation (priv->clock, label, ATK_RELATION_LABELLED_BY);
+#endif /* !HAVE_HILDON */
 
   /* Load the UI after we've connected the statusbar,
    * otherwise not all actions will have statusbar help.
@@ -2299,7 +2320,7 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->main_menu = gtk_ui_manager_get_widget (priv->ui_manager, MAIN_MENU_UI_PATH);
   priv->toolbar = gtk_ui_manager_get_widget (priv->ui_manager, TOOLBAR_UI_PATH);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   /* It's a bit ugly to mess with the toolbar like this,
    * but it's simpler than to implement a dedicated action
    * which creates a tool item which ellipsises its label...
@@ -2345,7 +2366,7 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_container_add (GTK_CONTAINER (window), main_vbox);
   gtk_widget_show (main_vbox);
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   hildon_window_set_menu (HILDON_WINDOW (window), GTK_MENU (priv->main_menu));
   hildon_window_add_toolbar (HILDON_WINDOW (window), GTK_TOOLBAR (priv->toolbar));
 #else
@@ -2353,17 +2374,17 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_box_pack_start (GTK_BOX (main_vbox), priv->toolbar, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (main_vbox), GTK_WIDGET (priv->statusbar), FALSE, FALSE, 0);
   gtk_widget_show (GTK_WIDGET (priv->statusbar));
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
   gtk_box_pack_start (GTK_BOX (main_vbox), GTK_WIDGET (priv->board), TRUE, TRUE, 0);
   gtk_widget_show (GTK_WIDGET (priv->board));
 
   /* Synchronise */
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   sync_game_score (priv->game, NULL, window);
   g_signal_connect (priv->game, "notify::score",
                     G_CALLBACK (sync_game_score), window);
-#endif /* !HAVE_MAEMO */
+#endif /* !HAVE_HILDON */
 
   sync_game_state (priv->game, NULL, window);
   g_signal_connect (priv->game, "notify::state",
@@ -2396,7 +2417,8 @@ aisleriot_window_init (AisleriotWindow *window)
   /* Initial focus is in the board */
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
 
-#ifdef HAVE_MAEMO
+  /* FIXMEchpe: make this #ifdef HAVE_MAEMO_3 after testing that it is indeed fixed */
+#ifdef HAVE_HILDON
   /* Bug alert! maemo#615 and maemo#875
    * Thank you, maemo developers! This bug just cost me 2 hours of my life.
    */
@@ -2407,7 +2429,7 @@ aisleriot_window_init (AisleriotWindow *window)
   }
 #endif
 
-#ifdef HAVE_MAEMO
+#ifdef HAVE_HILDON
   g_signal_connect (window, "notify::is-topmost",
                     G_CALLBACK (sync_window_topmost_cb), NULL);
 #endif
@@ -2424,7 +2446,7 @@ aisleriot_window_finalize (GObject *object)
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
 
-#ifndef HAVE_MAEMO
+#ifndef HAVE_HILDON
   if (priv->hint_dialog) {
     gtk_widget_destroy (priv->hint_dialog);
     g_assert (priv->hint_dialog == NULL);
