@@ -1,12 +1,19 @@
-import os, os.path
+import sys, os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR = os.path.join('/usr/local', 'share') 
-IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
-LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
-GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
-BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+if sys.modules["gnome_sudoku"].installed_mode:
+    APP_DATA_DIR = os.path.join('/usr/local', 'share') 
+    IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
+    LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
+    GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+    BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+else:
+    APP_DATA_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data') 
+    IMAGE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'images')
+    LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
+    GLADE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'glade')
+    BASE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data') 
 
 DOMAIN = 'gnome-games'
 gettext.bindtextdomain(DOMAIN, LOCALEDIR)
@@ -16,7 +23,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.21.4"
+VERSION = "2.21.5"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
