@@ -752,7 +752,7 @@ class SudokuNumberGrid (gtk.AspectFrame):
         if rect.width > rect.height: side = rect.height
         else: side = rect.width
         # we want our small spacing to be 1/15th the size of a box
-        spacing = int(rect.width / (self.group_size * SPACING_FACTOR))
+        spacing = float(side) / (self.group_size * SPACING_FACTOR)
         if spacing == 0: spacing = 1
         if hasattr(self,'small_spacing') and spacing == self.small_spacing:
             return
@@ -761,9 +761,9 @@ class SudokuNumberGrid (gtk.AspectFrame):
 
     def change_spacing (self, small_spacing):
         self.small_spacing = small_spacing
-        self.big_spacing = small_spacing*SMALL_TO_BIG_FACTOR
-        self.table.set_row_spacings(small_spacing)
-        self.table.set_col_spacings(small_spacing)
+        self.big_spacing = int(small_spacing*SMALL_TO_BIG_FACTOR)
+        self.table.set_row_spacings(int(small_spacing))
+        self.table.set_col_spacings(int(small_spacing))
         box_side = int(math.sqrt(self.group_size))
         for n in range(1,box_side):
             self.table.set_row_spacing(box_side*n-1,self.big_spacing)
@@ -1036,7 +1036,7 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                 for col in range(group_size):
                     index = row * 9 + col
                     if values[index] and not self.grid._get_(col,row):
-                        self.add_value(col,row,values[index])
+                        self.add_value_to_ui(col,row,values[index])
 
     @simple_debug
     def setup_grid (self, grid, group_size):
