@@ -1,7 +1,7 @@
 /*
  * games-sound.c: common sound player for gnome-games 
  *
- * Copyright © 2007 Andreas Røsdal
+ * Copyright © 2007-2008 Andreas Røsdal
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,17 +24,21 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#ifdef HAVE_GSTREAMER
-#include <gst/gst.h>
-#endif /* HAVE_GSTREAMER */
+#if defined(HAVE_GSTREAMER)
+  #include <gst/gst.h>
+#elif defined(HAVE_SDL_MIXER)
+  #include "SDL.h"
+  #include "SDL_mixer.h"
+#endif 
 
 #include "games-sound.h"
 
-#ifdef HAVE_GSTREAMER
-
-static GstElement *pipeline;
 static gboolean sound_enabled = FALSE;
 static gboolean sound_init = FALSE;
+
+
+#ifdef HAVE_GSTREAMER
+static GstElement *pipeline;
 static GThreadPool *threads;
 
 /* This function is called as a separate thread, playing the sound. */
@@ -86,10 +90,35 @@ games_sound_thread_run (gchar * data, gchar * user_data)
   g_free (fullname);
 }
 
-/* Initializes the games-sound support, GStreamer and threads. */
+#endif /* HAVE_GSTREAMER */
+
+
+#ifdef HAVE_SDL_MIXER
+static void
+games_sound_sdl_play (const gchar *filename)
+{
+  Mix_Chunk *wave = NULL;
+  gchar *name, *path;
+
+  name = g_strdup_printf ("%s.ogg", filename);
+  path = g_build_filename (SOUNDDIR, name, NULL);
+  g_free (name);
+
+  wave = Mix_LoadWAV (path);
+  if (wave == NULL) {
+    g_print (_("Error playing sound %s: %s\n"), path, Mix_GetError ());
+  }
+
+  Mix_PlayChannel (-1, wave, 0);
+  g_free (path);
+}
+#endif /* HAVE_SDL_MIXER */
+
+/* Initializes the games-sound support */
 static void
 games_sound_init (void)
 {
+#if defined(HAVE_GSTREAMER)
   GError *err = NULL;
 
   g_assert (g_thread_supported ());
@@ -100,9 +129,30 @@ games_sound_init (void)
 			       NULL, 10, FALSE, &err);
   sound_init = TRUE;
 
-}
+#elif defined(HAVE_SDL_MIXER)
 
-#endif /* HAVE_GSTREAMER */
+  const int audio_rate = MIX_DEFAULT_FREQUENCY;
+  const int audio_format = MIX_DEFAULT_FORMAT;
+  const int audio_channels = 2;
+
+/* Sounds don't sound good on Windows unless the buffer size is 4k,
+ * but this seems to cause strange behaviour on other systems,
+ * such as a delay before playing the sound. */
+#ifdef WIN32_NATIVE
+#define BUF_SIZE (4096)
+  const size_t buf_size = 4096;
+#else
+  const size_t buf_size = 1024;
+#endif
+
+  SDL_Init (SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE);
+
+  if (Mix_OpenAudio (audio_rate, audio_format, audio_channels, buf_size) < 0) {
+    g_warning ("Error calling Mix_OpenAudio\n");
+    return;
+  }
+#endif /* HAVE_SDL_MIXER */
+}
 
 /**
  * games_sound_add_option_group:
@@ -128,7 +178,7 @@ games_sound_add_option_group (GOptionContext *context)
 void
 games_sound_play (const gchar * filename)
 {
-#ifdef HAVE_GSTREAMER
+#if defined(HAVE_GSTREAMER)
   GError *err = NULL;
 
   if (!sound_enabled)
@@ -137,6 +187,15 @@ games_sound_play (const gchar * filename)
     games_sound_init ();
 
   g_thread_pool_push (threads, (gchar *) filename, &err);
+
+#elif defined(HAVE_SDL_MIXER)
+
+  if (!sound_enabled)
+    return;
+  if (!sound_init)
+    games_sound_init ();
+
+  games_sound_sdl_play (filename);
 #endif /* HAVE_GSTREAMER */
 }
 
@@ -149,9 +208,9 @@ games_sound_play (const gchar * filename)
 void
 games_sound_enable (gboolean enabled)
 {
-#ifdef HAVE_GSTREAMER
+#if defined(HAVE_GSTREAMER) || defined(HAVE_SDL_MIXER)
   sound_enabled = enabled;
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_GSTREAMER || HAVE_SDL_MIXER */
 }
 
 /**
@@ -162,11 +221,11 @@ games_sound_enable (gboolean enabled)
 gboolean
 games_sound_is_enabled (void)
 {
-#ifdef HAVE_GSTREAMER
+#if defined(HAVE_GSTREAMER) || defined(HAVE_SDL_MIXER)
   return sound_enabled;
 #else
   return FALSE;
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_GSTREAMER || HAVE_SDL_MIXER */
 }
 
 /**
@@ -177,9 +236,9 @@ games_sound_is_enabled (void)
 gboolean
 games_sound_is_available (void)
 {
-#ifdef HAVE_GSTREAMER
+#if defined(HAVE_GSTREAMER) || defined(HAVE_SDL_MIXER)
   return TRUE;
 #else
   return FALSE;
-#endif /* HAVE_GSTREAMER */
+#endif /* HAVE_GSTREAMER || HAVE_SDL_MIXER */
 }
