@@ -582,6 +582,8 @@ fill_tile_menu (GtkWidget * menu)
       g_free (s);
       continue;
     }
+      
+    // TODO: Strip off suffix (bug #406856)
 
     gchar** tileset_name = g_strsplit (s, ".", -1);
     gtk_combo_box_append_text (GTK_COMBO_BOX (menu), tileset_name[0]);
@@ -1550,9 +1552,11 @@ main (int argc, char *argv[])
   init_game ();
   update_score_state ();
 
+  /* Don't leave the keyboard focus on the toolbar */
+  gtk_widget_grab_focus (board);
+
   /* Note: we have to have a layout loaded before here so that the
    * window knows how big to make the tiles. */
-
   gtk_widget_show_all (window);
 
   if (!games_conf_get_boolean (NULL, KEY_SHOW_TOOLBAR, NULL))
